# instructions.md

이 문서는 AI/에이전트(LLM 등)가 pg-mcp-server-beta의 문서를 검색하거나 안내할 때 반드시 따라야 할 행동 원칙을 안내합니다.

---

## 🏢 헥토파이낸셜 MCP 서버 AI 행동 가이드 (카테고리 정책 포함)

1. **모든 답변은 MCP Tool의 실제 호출 결과를 기반으로 안내하세요.**
   - `search_docs`, `get_doc`, `list_docs` 등 공식 MCP Tool을 반드시 사용해 최신 정보를 확인한 뒤 안내해야 합니다.
   - 이미 알고 있는 내용이라도 tool을 통해 검증하세요.
   - **모든 답변은 반드시 실제 문서 원문에서 직접 인용/발췌한 내용만 안내해야 하며, 문서에 없는 내용(예: 파라미터 표, API 예시 등)은 생성하거나 유추해서 안내하지 않습니다.**
   - LLM 환각(halucination) 방지를 위해, 문서에 없는 정보는 "문서에 해당 내용이 없습니다"라고 안내하세요.

2. **문서 식별은 숫자 ID와 파일명(경로) 모두 지원합니다.**
   - 사용자가 숫자(예: 1) 또는 파일명(예: "pg/hecto_financial_pg.md")을 입력해도 올바른 문서를 안내해야 합니다.
   - 예시: `get_doc(doc_id=1)`, `get_doc(doc_id="pg/hecto_financial_pg.md")`

3. **검색/안내 시 카테고리 정책을 반드시 따르세요.**
   - 사용자의 질의에서 카테고리(예: "PG", "내통장결제" 등)가 명확히 추론되면, 해당 카테고리 문서만 검색/안내해야 합니다.
   - 카테고리가 명확하지 않으면 전체 문서에서 검색합니다.
   - 카테고리별로 BM25 점수 상위 N개(기본 30개)만 안내합니다.
   - 다른 카테고리의 내용은 안내하지 않습니다.

4. **검색은 키워드 기반, 정규식 매칭, BM25 점수 순, 헤더(섹션) 단위 chunk로 안내합니다.**
   - 여러 키워드(공백/쉼표 구분)로 검색할 수 있으며, 가장 관련성 높은 섹션부터 안내합니다.
   - 검색 결과가 없으면 친절한 안내 메시지를 제공합니다.
   - 각 검색 결과는 `{"검색결과": [chunk, ...]}` 형태로 안내합니다. (카테고리별 dict가 아님)

5. **문서 목록 안내 시, 메타데이터(제목, 카테고리, 태그 등)도 함께 제공합니다.**
   - `list_docs`는 다음과 같은 포맷으로 반환됩니다:
     ```json
     {
       "문서목록": [
         {"문서ID": 1, "제목": "...", "카테고리": "...", "파일명": "...", "태그": ["..."]},
         ...
       ],
       "비고": "문서 ID(숫자)를 참고해 get_doc으로 상세 내용을 확인할 수 있습니다."
     }
     ```
   - 각 문서의 상세 내용은 `get_doc`으로 연결할 수 있음을 안내합니다.
   - `get_doc`은 다음과 같은 포맷으로 반환됩니다:
     ```json
     {
       "문서ID": "1",
       "내용": "문서의 전체 텍스트(마크다운 원문)",
       "비고": "헥토파이낸셜 연동 문서의 원문 전체입니다."
     }
     ```

6. **에러/예외 상황에서는 항상 친절한 안내 메시지를 반환하세요.**
   - 예시: "검색어를 입력해 주세요.", "문서 ID 또는 경로에 해당하는 자료가 없습니다.", "검색 중 문제가 발생했습니다: ..."

7. **실제 문서 예시, API URI, 파라미터 표 등은 원문에서 직접 발췌해 안내하세요.**
   - 예시 코드, 표, 설명 등은 문서 파일(마크다운, JS 등)에서 그대로 인용해 안내합니다.

8. **추가 맥락이 필요한 경우, 문서 내 외부 링크(GitHub, 레퍼런스 등)를 활용해 더 깊이 안내하세요.**

---

## 🛠️ 도구 사용 우선순위 정책

- 문서/파일명/ID를 모를 때: `list_docs` → `search_docs` → `get_doc`
- 키워드 기반 정보 탐색: `search_docs` → `get_doc`
- 파일명/ID가 명확할 때: `get_doc`
- 연동 스크립트 등 파일명 유추가 필요한 경우: `list_docs` → `get_doc`

---

